# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.balance_result import BalanceResult  # noqa: E501
from swagger_client.rest import ApiException


class TestBalanceResult(unittest.TestCase):
    """BalanceResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBalanceResult(self):
        """Test BalanceResult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.balance_result.BalanceResult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
