# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PaginatedResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'page': 'int',
        'page_size': 'int',
        'total': 'int',
        'total_pages': 'int',
        'result': 'object'
    }

    attribute_map = {
        'page': 'page',
        'page_size': 'pageSize',
        'total': 'total',
        'total_pages': 'totalPages',
        'result': 'result'
    }

    def __init__(self, page=None, page_size=None, total=None, total_pages=None, result=None):  # noqa: E501
        """PaginatedResult - a model defined in Swagger"""  # noqa: E501
        self._page = None
        self._page_size = None
        self._total = None
        self._total_pages = None
        self._result = None
        self.discriminator = None
        if page is not None:
            self.page = page
        if page_size is not None:
            self.page_size = page_size
        if total is not None:
            self.total = total
        if total_pages is not None:
            self.total_pages = total_pages
        if result is not None:
            self.result = result

    @property
    def page(self):
        """Gets the page of this PaginatedResult.  # noqa: E501


        :return: The page of this PaginatedResult.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this PaginatedResult.


        :param page: The page of this PaginatedResult.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def page_size(self):
        """Gets the page_size of this PaginatedResult.  # noqa: E501


        :return: The page_size of this PaginatedResult.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this PaginatedResult.


        :param page_size: The page_size of this PaginatedResult.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def total(self):
        """Gets the total of this PaginatedResult.  # noqa: E501


        :return: The total of this PaginatedResult.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this PaginatedResult.


        :param total: The total of this PaginatedResult.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def total_pages(self):
        """Gets the total_pages of this PaginatedResult.  # noqa: E501


        :return: The total_pages of this PaginatedResult.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this PaginatedResult.


        :param total_pages: The total_pages of this PaginatedResult.  # noqa: E501
        :type: int
        """

        self._total_pages = total_pages

    @property
    def result(self):
        """Gets the result of this PaginatedResult.  # noqa: E501


        :return: The result of this PaginatedResult.  # noqa: E501
        :rtype: object
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this PaginatedResult.


        :param result: The result of this PaginatedResult.  # noqa: E501
        :type: object
        """

        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaginatedResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaginatedResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
