# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NetInfoPeerConnectionStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'duration': 'str',
        'send_monitor': 'NetInfoPeerConnectionStatusMonitor',
        'recv_monitor': 'NetInfoPeerConnectionStatusMonitor',
        'channels': 'list[NetInfoPeerConnectionStatusChannel]'
    }

    attribute_map = {
        'duration': 'duration',
        'send_monitor': 'sendMonitor',
        'recv_monitor': 'recvMonitor',
        'channels': 'channels'
    }

    def __init__(self, duration=None, send_monitor=None, recv_monitor=None, channels=None):  # noqa: E501
        """NetInfoPeerConnectionStatus - a model defined in Swagger"""  # noqa: E501
        self._duration = None
        self._send_monitor = None
        self._recv_monitor = None
        self._channels = None
        self.discriminator = None
        if duration is not None:
            self.duration = duration
        if send_monitor is not None:
            self.send_monitor = send_monitor
        if recv_monitor is not None:
            self.recv_monitor = recv_monitor
        if channels is not None:
            self.channels = channels

    @property
    def duration(self):
        """Gets the duration of this NetInfoPeerConnectionStatus.  # noqa: E501


        :return: The duration of this NetInfoPeerConnectionStatus.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this NetInfoPeerConnectionStatus.


        :param duration: The duration of this NetInfoPeerConnectionStatus.  # noqa: E501
        :type: str
        """

        self._duration = duration

    @property
    def send_monitor(self):
        """Gets the send_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501


        :return: The send_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501
        :rtype: NetInfoPeerConnectionStatusMonitor
        """
        return self._send_monitor

    @send_monitor.setter
    def send_monitor(self, send_monitor):
        """Sets the send_monitor of this NetInfoPeerConnectionStatus.


        :param send_monitor: The send_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501
        :type: NetInfoPeerConnectionStatusMonitor
        """

        self._send_monitor = send_monitor

    @property
    def recv_monitor(self):
        """Gets the recv_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501


        :return: The recv_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501
        :rtype: NetInfoPeerConnectionStatusMonitor
        """
        return self._recv_monitor

    @recv_monitor.setter
    def recv_monitor(self, recv_monitor):
        """Sets the recv_monitor of this NetInfoPeerConnectionStatus.


        :param recv_monitor: The recv_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501
        :type: NetInfoPeerConnectionStatusMonitor
        """

        self._recv_monitor = recv_monitor

    @property
    def channels(self):
        """Gets the channels of this NetInfoPeerConnectionStatus.  # noqa: E501


        :return: The channels of this NetInfoPeerConnectionStatus.  # noqa: E501
        :rtype: list[NetInfoPeerConnectionStatusChannel]
        """
        return self._channels

    @channels.setter
    def channels(self, channels):
        """Sets the channels of this NetInfoPeerConnectionStatus.


        :param channels: The channels of this NetInfoPeerConnectionStatus.  # noqa: E501
        :type: list[NetInfoPeerConnectionStatusChannel]
        """

        self._channels = channels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NetInfoPeerConnectionStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetInfoPeerConnectionStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
