# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TokenPriceResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp': 'int',
        'open': 'str',
        'high': 'str',
        'low': 'str',
        'close': 'str'
    }

    attribute_map = {
        'timestamp': 'timestamp',
        'open': 'open',
        'high': 'high',
        'low': 'low',
        'close': 'close'
    }

    def __init__(self, timestamp=None, open=None, high=None, low=None, close=None):  # noqa: E501
        """TokenPriceResult - a model defined in Swagger"""  # noqa: E501
        self._timestamp = None
        self._open = None
        self._high = None
        self._low = None
        self._close = None
        self.discriminator = None
        if timestamp is not None:
            self.timestamp = timestamp
        if open is not None:
            self.open = open
        if high is not None:
            self.high = high
        if low is not None:
            self.low = low
        if close is not None:
            self.close = close

    @property
    def timestamp(self):
        """Gets the timestamp of this TokenPriceResult.  # noqa: E501


        :return: The timestamp of this TokenPriceResult.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this TokenPriceResult.


        :param timestamp: The timestamp of this TokenPriceResult.  # noqa: E501
        :type: int
        """

        self._timestamp = timestamp

    @property
    def open(self):
        """Gets the open of this TokenPriceResult.  # noqa: E501


        :return: The open of this TokenPriceResult.  # noqa: E501
        :rtype: str
        """
        return self._open

    @open.setter
    def open(self, open):
        """Sets the open of this TokenPriceResult.


        :param open: The open of this TokenPriceResult.  # noqa: E501
        :type: str
        """

        self._open = open

    @property
    def high(self):
        """Gets the high of this TokenPriceResult.  # noqa: E501


        :return: The high of this TokenPriceResult.  # noqa: E501
        :rtype: str
        """
        return self._high

    @high.setter
    def high(self, high):
        """Sets the high of this TokenPriceResult.


        :param high: The high of this TokenPriceResult.  # noqa: E501
        :type: str
        """

        self._high = high

    @property
    def low(self):
        """Gets the low of this TokenPriceResult.  # noqa: E501


        :return: The low of this TokenPriceResult.  # noqa: E501
        :rtype: str
        """
        return self._low

    @low.setter
    def low(self, low):
        """Sets the low of this TokenPriceResult.


        :param low: The low of this TokenPriceResult.  # noqa: E501
        :type: str
        """

        self._low = low

    @property
    def close(self):
        """Gets the close of this TokenPriceResult.  # noqa: E501


        :return: The close of this TokenPriceResult.  # noqa: E501
        :rtype: str
        """
        return self._close

    @close.setter
    def close(self, close):
        """Sets the close of this TokenPriceResult.


        :param close: The close of this TokenPriceResult.  # noqa: E501
        :type: str
        """

        self._close = close

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TokenPriceResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TokenPriceResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
