# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.platform_api import PlatformApi  # noqa: E501
from swagger_client.rest import ApiException


class TestPlatformApi(unittest.TestCase):
    """PlatformApi unit test stubs"""

    def setUp(self):
        self.api = PlatformApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_get_interop_get(self):
        """Test case for api_v1_get_interop_get

        """
        pass

    def test_api_v1_get_platform_get(self):
        """Test case for api_v1_get_platform_get

        """
        pass

    def test_api_v1_get_platforms_get(self):
        """Test case for api_v1_get_platforms_get

        """
        pass


if __name__ == '__main__':
    unittest.main()
